Fields
------

A ZnTrack field is used to define inputs and outputs for a :term:`Node` on the class level.
The following fields are available:

.. autofunction:: zntrack.params
.. autofunction:: zntrack.deps
.. autofunction:: zntrack.outs
.. autofunction:: zntrack.metrics
.. autofunction:: zntrack.plots

.. autofunction:: zntrack.params_path
.. autofunction:: zntrack.deps_path
.. autofunction:: zntrack.outs_path
.. autofunction:: zntrack.metrics_path
.. autofunction:: zntrack.plots_path

It is possible to define custom fields by using :meth:`zntrack.field`.

.. autofunction:: zntrack.field
